## BETA SOFTWARE. DO NOT USE WHEN FAILURE WILL HAVE CONSEQUENCES.

# Rabbit Typing, for Python

Rabbit Typing, as opposed to [Duck Typing](https://www.python.org/) and
[Monkey Typing](https://github.com/Instagram/MonkeyType), is a brute force
dynamic type inference approach which attempts to infer argument types for a
library function.

![A rabbit](https://github.com/strawberry-jam-cabal/aft/raw/master/rabbit.jpg)

